#!/usr/bin/python
"""
Copyright (C) 2013 2014 2015 Johan Mattsson

This library is free software; you can redistribute it and/or modify 
it under the terms of the GNU Lesser General Public License as 
published by the Free Software Foundation; either version 3 of the 
License, or (at your option) any later version.

This library is distributed in the hope that it will be useful, but 
WITHOUT ANY WARRANTY; without even the implied warranty of 
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
Lesser General Public License for more details.
"""

XMLBIRD_VERSION = '1.2.9'
LIBXMLBIRD_SO_VERSION_MAJOR = '1'
LIBXMLBIRD_SO_VERSION_MINOR = '0'
LIBXMLBIRD_SO_VERSION = LIBXMLBIRD_SO_VERSION_MAJOR;
